pub enum Change {
Added {
index: usize,
kind: String,
key: String,
},
Removed {
index: usize,
kind: String,
key: String,
},
Changed {
index: usize,
kind: String,
key: String,
baseline: Value,
new: Value,
},
}Expand description
A single change.
Variants
Added
A step present in the new trace but missing in the baseline.
Removed
A step present in the baseline but missing in the new trace.
Changed
A step present in both but with a different payload.